pub struct ConversionEventUserClickIds {
pub fbc: Option<String>,
pub fbp: Option<String>,
pub gclid: Option<String>,
pub gbraid: Option<String>,
pub wbraid: Option<String>,
}Expand description
ConversionEventUserClickIds : Platform click identifiers captured from the originating ad click.
Fields
fbc: Option<String>Meta click ID (from fbclid URL param).
fbp: Option<String>Meta browser ID (_fbp cookie).
gclid: Option<String>Google click ID (from gclid URL param).
gbraid: Option<String>Google iOS 14.5+ app attribution ID.
wbraid: Option<String>Google iOS 14.5+ web-to-app attribution ID.
Implementations
Sourceimpl ConversionEventUserClickIds
impl ConversionEventUserClickIds
Sourcepub fn new() -> ConversionEventUserClickIds
pub fn new() -> ConversionEventUserClickIds
Platform click identifiers captured from the originating ad click.