pub struct ReplyToInboxPostRequest {
pub account_id: String,
pub message: String,
pub attachment_url: Option<String>,
pub comment_id: Option<String>,
pub parent_cid: Option<String>,
pub root_uri: Option<String>,
pub root_cid: Option<String>,
}Fields
account_id: Stringmessage: Stringattachment_url: Option<String>(Facebook only) URL of an image to attach, publishing a photo comment alongside the text. The URL must be publicly accessible so Meta can fetch it. Returns 400 for other platforms.
comment_id: Option<String>Reply to specific comment (optional)
parent_cid: Option<String>(Bluesky only) Parent content identifier
root_uri: Option<String>(Bluesky only) Root post URI
root_cid: Option<String>(Bluesky only) Root post CID
Implementations
Sourceimpl ReplyToInboxPostRequest
impl ReplyToInboxPostRequest
pub fn new(account_id: String, message: String) -> ReplyToInboxPostRequest