pub struct UpdateAdRequestTargeting {
pub age_min: Option<i32>,
pub age_max: Option<i32>,
pub countries: Option<Vec<String>>,
pub interests: Option<Vec<UpdateAdRequestTargetingInterestsInner>>,
}Expand description
UpdateAdRequestTargeting : Meta-only. Targeting updates for other platforms are not supported after creation.
Fields
age_min: Option<i32>age_max: Option<i32>countries: Option<Vec<String>>interests: Option<Vec<UpdateAdRequestTargetingInterestsInner>>Interest objects from /v1/ads/interests. Each must include id and name.
Implementations
Sourceimpl UpdateAdRequestTargeting
impl UpdateAdRequestTargeting
Sourcepub fn new() -> UpdateAdRequestTargeting
pub fn new() -> UpdateAdRequestTargeting
Meta-only. Targeting updates for other platforms are not supported after creation.