pub struct WebhookPayloadCallEnded {
pub id: String,
pub event: Event,
pub call: Box<WebhookPayloadCallEndedCall>,
pub account: Box<InboxWebhookAccount>,
pub timestamp: String,
}Expand description
WebhookPayloadCallEnded : Webhook payload for the call.ended event. Fires on call hangup with the duration and a zero-markup billing breakdown.
Fields
id: Stringevent: Eventcall: Box<WebhookPayloadCallEndedCall>account: Box<InboxWebhookAccount>timestamp: StringImplementations
Sourceimpl WebhookPayloadCallEnded
impl WebhookPayloadCallEnded
Sourcepub fn new(
id: String,
event: Event,
call: WebhookPayloadCallEndedCall,
account: InboxWebhookAccount,
timestamp: String,
) -> WebhookPayloadCallEnded
pub fn new( id: String, event: Event, call: WebhookPayloadCallEndedCall, account: InboxWebhookAccount, timestamp: String, ) -> WebhookPayloadCallEnded
Webhook payload for the call.ended event. Fires on call hangup with the duration and a zero-markup billing breakdown.